==> haskell-vty5-5.39-104-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-vty5.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 vty
version:              5.39
visibility:           public
id:                   vty-5.39-IzpzW9ooAXyC6UedcWj3fC
key:                  vty-5.39-IzpzW9ooAXyC6UedcWj3fC
license:              BSD-3-Clause
maintainer:           Jonathan Daugherty (cygnus@foobox.com)
author:               AUTHORS
homepage:             https://github.com/jtdaugherty/vty
synopsis:             A simple terminal UI library
description:
    vty is terminal GUI library in the niche of ncurses. It is intended to
    be easy to use and to provide good support for common terminal types.

    See the @vty-examples@ package as well as the program
    @examples/interactive_terminal_test.hs@ included in the @vty@
    repository for examples on how to use the library.

    Import the @Graphics.Vty@ convenience module to get access to the core
    parts of the library.

    &#169; 2006-2007 Stefan O'\''Rear; BSD3 license.

    &#169; Corey O'\''Connor; BSD3 license.

    &#169; Jonathan Daugherty; BSD3 license.

category:             User Interfaces
abi:                  bd8fd5c8305edf6956201862c4789a74
exposed:              True
exposed-modules:
    Data.Terminfo.Eval Data.Terminfo.Parse Graphics.Text.Width
    Graphics.Vty Graphics.Vty.Attributes Graphics.Vty.Attributes.Color
    Graphics.Vty.Attributes.Color240 Graphics.Vty.Config
    Graphics.Vty.Debug Graphics.Vty.DisplayAttributes
    Graphics.Vty.Error Graphics.Vty.Image Graphics.Vty.Image.Internal
    Graphics.Vty.Inline Graphics.Vty.Inline.Unsafe Graphics.Vty.Input
    Graphics.Vty.Input.Classify Graphics.Vty.Input.Classify.Parse
    Graphics.Vty.Input.Classify.Types Graphics.Vty.Input.Events
    Graphics.Vty.Input.Focus Graphics.Vty.Input.Loop
    Graphics.Vty.Input.Mouse Graphics.Vty.Input.Paste
    Graphics.Vty.Input.Terminfo Graphics.Vty.Output
    Graphics.Vty.Output.Interface Graphics.Vty.Output.Mock
    Graphics.Vty.Output.TerminfoBased Graphics.Vty.Output.XTermColor
    Graphics.Vty.Picture Graphics.Vty.PictureToSpans Graphics.Vty.Span
    Graphics.Vty.UnicodeWidthTable.IO
    Graphics.Vty.UnicodeWidthTable.Install
    Graphics.Vty.UnicodeWidthTable.Query
    Graphics.Vty.UnicodeWidthTable.Types

hidden-modules:       Graphics.Vty.Input.Terminfo.ANSIVT
import-dirs:          /usr/lib/ghc-9.4.8/site-local/vty-5.39
library-dirs:         /usr/lib/ghc-9.4.8/site-local/vty-5.39
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/vty-5.39
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-vty5
hs-libraries:         HSvty-5.39-IzpzW9ooAXyC6UedcWj3fC
depends:
    ansi-terminal-1.0.2-HSq0v3QUl8T11Wgx1QLnTe base-4.17.2.1
    binary-0.8.9.1 blaze-builder-0.4.4.1-1AsqmJqbexUDW45IoYp4gz
    bytestring-0.11.5.3 containers-0.6.7 deepseq-1.4.8.0
    directory-1.3.7.1 filepath-1.4.2.2
    microlens-0.4.14.0-71jOCsiFFF8LaovsPy6HDt
    microlens-mtl-0.2.1.0-LWyutRK1cqlCk2SYzoFhAy
    microlens-th-0.4.3.17-GRXwDxs8Aw09PQskuAg669 mtl-2.2.2
    parsec-3.1.16.1 stm-2.5.1.0 terminfo-0.4.1.5 text-2.0.2
    transformers-0.5.6.2 unix-2.7.3
    utf8-string-1.0.2-D0oARDqSiCF3CIA0pPBIDm
    vector-0.13.2.0-DhQEcquLn8PDmAHUsOvAGS

haddock-interfaces:   /usr/share/doc/haskell-vty5/html/vty.haddock
haddock-html:         /usr/share/doc/haskell-vty5/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-vty5-5.39-109-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-vty5.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 vty
version:              5.39
visibility:           public
id:                   vty-5.39-ESTphsyqQRg7goGWUcRx80
key:                  vty-5.39-ESTphsyqQRg7goGWUcRx80
license:              BSD-3-Clause
maintainer:           Jonathan Daugherty (cygnus@foobox.com)
author:               AUTHORS
homepage:             https://github.com/jtdaugherty/vty
synopsis:             A simple terminal UI library
description:
    vty is terminal GUI library in the niche of ncurses. It is intended to
    be easy to use and to provide good support for common terminal types.

    See the @vty-examples@ package as well as the program
    @examples/interactive_terminal_test.hs@ included in the @vty@
    repository for examples on how to use the library.

    Import the @Graphics.Vty@ convenience module to get access to the core
    parts of the library.

    &#169; 2006-2007 Stefan O'\''Rear; BSD3 license.

    &#169; Corey O'\''Connor; BSD3 license.

    &#169; Jonathan Daugherty; BSD3 license.

category:             User Interfaces
abi:                  9489e32b72175f9766b22e0267c917bc
exposed:              True
exposed-modules:
    Data.Terminfo.Eval Data.Terminfo.Parse Graphics.Text.Width
    Graphics.Vty Graphics.Vty.Attributes Graphics.Vty.Attributes.Color
    Graphics.Vty.Attributes.Color240 Graphics.Vty.Config
    Graphics.Vty.Debug Graphics.Vty.DisplayAttributes
    Graphics.Vty.Error Graphics.Vty.Image Graphics.Vty.Image.Internal
    Graphics.Vty.Inline Graphics.Vty.Inline.Unsafe Graphics.Vty.Input
    Graphics.Vty.Input.Classify Graphics.Vty.Input.Classify.Parse
    Graphics.Vty.Input.Classify.Types Graphics.Vty.Input.Events
    Graphics.Vty.Input.Focus Graphics.Vty.Input.Loop
    Graphics.Vty.Input.Mouse Graphics.Vty.Input.Paste
    Graphics.Vty.Input.Terminfo Graphics.Vty.Output
    Graphics.Vty.Output.Interface Graphics.Vty.Output.Mock
    Graphics.Vty.Output.TerminfoBased Graphics.Vty.Output.XTermColor
    Graphics.Vty.Picture Graphics.Vty.PictureToSpans Graphics.Vty.Span
    Graphics.Vty.UnicodeWidthTable.IO
    Graphics.Vty.UnicodeWidthTable.Install
    Graphics.Vty.UnicodeWidthTable.Query
    Graphics.Vty.UnicodeWidthTable.Types

hidden-modules:       Graphics.Vty.Input.Terminfo.ANSIVT
import-dirs:          /usr/lib/ghc-9.6.7.20250817/site-local/vty-5.39
library-dirs:         /usr/lib/ghc-9.6.7.20250817/site-local/vty-5.39
library-dirs-static:  /usr/lib/ghc-9.6.7.20250817/site-local/vty-5.39
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-vty5
hs-libraries:         HSvty-5.39-ESTphsyqQRg7goGWUcRx80
depends:
    ansi-terminal-1.1-4EeIQsn6Wrq78PCXTndXTh base-4.18.3.0
    binary-0.8.9.1 blaze-builder-0.4.4.1-3S17E8wm5XE4Chq6ULhvf8
    bytestring-0.11.5.4 containers-0.6.7 deepseq-1.4.8.1
    directory-1.3.8.5 filepath-1.4.301.0
    microlens-0.4.14.0-4ENPj0tHNR0GzcdT8Xo5Q8
    microlens-mtl-0.2.1.0-BPqflcywilRLKDKsRXDgDa
    microlens-th-0.4.3.17-F1IcXkuPeIB4kMaxwhk9vS mtl-2.3.1
    parsec-3.1.16.1 stm-2.5.1.0 terminfo-0.4.1.6 text-2.0.2
    transformers-0.6.1.0 unix-2.8.6.0
    utf8-string-1.0.2-shiuprzUpU7bW4pJ3bW0
    vector-0.13.2.0-BINMV7y6ibUKgFTnLXEi1A

haddock-interfaces:   /usr/share/doc/haskell-vty5/html/vty.haddock
haddock-html:         /usr/share/doc/haskell-vty5/html
' | '/usr/bin/ghc-pkg-9.6.7.20250817' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
